/*
 * Copyright (c) 2015, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef __BOARD_H__
#define __BOARD_H__

#ifdef __cplusplus
extern "C" {
#endif

/** ============================================================================
 *  Includes
 *  ==========================================================================*/
#include <ti/drivers/PIN.h>
#include <driverlib/ioc.h>

/** ============================================================================
 *  Externs
 *  ==========================================================================*/
extern const PIN_Config BoardGpioInitTable[];

/** ============================================================================
 *  Defines
 *  ==========================================================================*/

/* Identify as CC2650 LaunchPad */
//#define CC2650LP

/* Same RF Configuration as 7x7 EM */
#define CC2650EM_7ID

/* Mapping of pins to board signals using general board aliases
 *      <board signal alias>        <pin mapping>
 */

/* AFE */
#define VOLTAGE_RANGE_SWITCH        IOID_13
#define MEASUREMENT_MODE_SWITCH     IOID_12

#define VOLTAGE_RANGE_SELECT_1   	IOID_9
#define VOLTAGE_RANGE_SELECT_0   	IOID_10
#define CURRENT_RANGE_SELECT	   	IOID_11

#define AFE_GAIN_SELECT	   			IOID_14
#define CURRENT_SHUNT_ISOLATE	 	IOID_22

/* ADS8885 */
#define ADS8885_MISO           		IOID_6
#define ADS8885_MOSI           		IOID_8
#define ADS8885_SCLK            	IOID_7
#define ADS8885_CNVST          		IOID_5
#define ADS8885_CSN			       	IOID_30		//not used

/* BQ27426 */
#define BQ27426_SCL            		IOID_17
#define BQ27426_SDA             	IOID_18
#define ENABLE_BQ27426				IOID_19

/* RF430 */
#define RF430_SCL            		IOID_0
#define RF430_SDA             		IOID_1
#define RF430_IRQ             		IOID_2
#define RF430_nRST            		IOID_3
#define RF430_VCORE            		IOID_4

/* RF430 */
#define CC2640_WAKE_UP         		IOID_15
#define MSP430_RESET   				IOID_16

/* POWER MANAGEMENT */
#define AFE_DCDC_ENABLE           	IOID_20
#define AFE_LDO_ENABLE           	IOID_21

/* UNUSED */
#define UNUSED_1		           	IOID_23
#define UNUSED_2		           	IOID_24
#define UNUSED_3		           	IOID_25
#define UNUSED_4		           	IOID_26
#define UNUSED_5		           	IOID_27
#define UNUSED_6		           	IOID_28
#define UNUSED_7		           	IOID_29


/** ============================================================================
 *  Number of peripherals and their names
 *  ==========================================================================*/

/*!
 *  @def    CC2650_LAUNCHXL_I2CName
 *  @brief  Enum of I2C names on the CC2650 dev board
 */
typedef enum WDMM_I2CName {
    WDMM_I2C0 = 0,
	WDMM_I2C1,

    WDMM_I2CCOUNT
} WDMM_I2CName;

/*!
 *  @def    WDMM_SPIName
 *  @brief  Enum of SPI names on the WDMM board
 */
typedef enum WDMM_SPIName {
    WDMM_SPI0 = 0,
	WDMM_SPI1,
    WDMM_SPICOUNT
} WDMM_SPIName;


/*!
 *  @def    CC2650_LAUNCHXL_UdmaName
 *  @brief  Enum of DMA buffers
 */
typedef enum CC2650_LAUNCHXL_UdmaName {
    CC2650_LAUNCHXL_UDMA0 = 0,

    CC2650_LAUNCHXL_UDMACOUNT
} CC2650_LAUNCHXL_UdmaName;

#ifdef __cplusplus
}
#endif

#endif /* __BOARD_H__ */
